<template>
  <div id="customerChart"></div>
</template>

<script>
import * as echarts from "echarts";
import { reactive, onMounted, watch, nextTick } from "vue";
import {
  qxshChartList,
  pfshChartList,
  qxshControllerByTime,
  queryReal,
  forecastAnalyse,
} from "@/api/api.js";
import { useStore } from "vuex";
export default {
  //import引入的组件需要注入到对象中才能使用
  components: {},
  props: ["POIName", "POIType"],
  setup(props) {
    const store = useStore();
    let data = reactive({
      chartX: [],
      chartY: [],
      ssName: [],
      // 处理预测和实际对比表
      chartReal: [],
    });
    // watch(
    //   () => props.POIName,
    //   (nVal, oVal) => {
    //     getChartData(nVal, props.POIType);
    //   },
    //   { deep: true }
    // );
    // watch(
    //   () => store.state.POIname,
    //   (nVal, oVal) => {
    //     getChartData(nVal, store.state.POItype);
    //   },
    //   { deep: true }
    // );
    watch(
      () => store.state.YCstate,
      (nVal, oVal) => {
        getChartData(store.state.POIname, store.state.POItype);
      },
      { deep: true }
    );

    function nowSize(val, initWidth = 1920) {
      let nowClientWidth = document.documentElement.clientWidth;

      return val * (nowClientWidth / initWidth);
    }

    const getChartData = async (e, type) => {
      data.chartX = [];
      data.chartY = [];
      data.chartReal = [];

      var dt;
      var real;

      switch (type) {
        case "WY":
          dt = await qxshControllerByTime(e);
          // dt = await qxshControllerByTime({ name: e });
          break;
        case "CJ":
          dt = await qxshControllerByTime({ name: e });
          break;
        case "SS":
          dt = await pfshChartList({ name: e });

          break;
        case "WYY":
          dt = await forecastAnalyse({
            beginTime: store.state.ycleftTime,
            endTime: store.state.ycrightTime,
            name: e,
          });
          // dt = await qxshControllerByTime({
          //   leftTime: store.state.ycleftTime,
          //   rightTime: store.state.ycrightTime,
          //   name: e,
          // });

          break;
        // case "YZ":
        //   dt = await axios.get(`${jsonUrl}/json/yssh_qxsh.json`, {}, headers);
        //   break;
        // 对比
        case "CWYY":
          dt = await forecastAnalyse({
            beginTime: store.state.ycleftTime,
            endTime: store.state.ycrightTime,
            name: e,
          });
          real = await forecastAnalyse({
            beginTime: store.state.ycleftTime,
            endTime: store.state.ycrightTime,
            name: e,
          });
          // dt = await qxshControllerByTime({
          //   leftTime: store.state.ycleftTime,
          //   rightTime: store.state.ycrightTime,
          //   name: e,
          // });
          // real = await queryReal({
          //   leftTime: store.state.ycleftTime,
          //   rightTime: store.state.ycrightTime,
          //   name: e,
          // });
          break;
      }

      if (dt.result) {
        if (type == "WYY" || type == "CWYY") {
          dt.result.forEach((v) => {
            data.chartX.push(v.time);
            data.chartY.push(v.forecastValue);
          });
        } else {
          dt.result.forEach((v) => {
            data.chartX.push(v.time);
            data.chartY.push(v.value);
          });
        }
        // dt.result.forEach((v) => {
        //   let time = v.time.length
        //   data.chartX.push(v.time);
        //   data.chartY.push(Number(v.value).toFixed(3));

        // });
      } else {
        data.chartX = [];
        data.chartY = [];
        data.chartReal = [];
      }
      if (type == "CWYY" && real.result) {
        real.result.forEach((v) => {
          data.chartReal.push(v.practicalValue);
          // data.chartReal.push(Number(v.value).toFixed(2));
        });
      }

      nextTick(() => {
        chart(type);
      });
    };
    const chart = (type) => {
      let myChart = echarts.init(document.getElementById("customerChart"));
      // 绘制图表
      myChart.setOption({
        title: {
          text: store.state.POIname,
          textStyle: {
            color: "#fff",
            fontSize: nowSize(12),
          },
        },
        tooltip: {
          trigger: "axis",
          textStyle: {
            fontSize: nowSize(12),
          },
          axisPointer: {
            type: "cross",
            label: {
              backgroundColor: "#fff",
              color: "#000",
            },
          },
        },
        // legend: {
        //   data: [props.POIName],
        //   textStyle: {
        //     color: "#fff",
        //   },
        // },

        grid: {
          left: "6%",
          right: "6%",
          bottom: "25%",
          top: "15%",
          containLabel: true,
        },
        xAxis: [
          {
            type: "category",
            boundaryGap: true,
            data: data.chartX,
            axisLabel: {
              padding: [10, 0, 0, 0],
              color: "#fff",
              textStyle: {
                fontSize: nowSize(14),
                itemSize: "",
              },
            },
          },
        ],
        yAxis: [
          {
            type: "value",
            axisLabel: {
              color: "#fff",
              textStyle: {
                fontSize: nowSize(14),
                itemSize: "",
              },
            },
            scale: true,
            // min: "0.1", // 最小值
          },
        ],
        dataZoom: [
          {
            type: "inside",
            start: 0,
            end: 10,
            textStyle: {
              color: "#fff", //滚动条两边字体样式
            },
          },
          {
            start: 0,
            end: 10,
          },
        ],
        series: [
          {
            name: store.state.POIname,
            type: "line",
            // stack: "Total",
            areaStyle: {},
            symbol: "none",
            sampling: "lttb",
            emphasis: {
              focus: "series",
            },
            data: data.chartY,
          },
          {
            name: "实际",
            type: "line",
            // stack: "Total",
            areaStyle: {},
            symbol: "none",
            sampling: "lttb",
            emphasis: {
              focus: "series",
            },
            data: type == "CWYY" ? data.chartReal : [],
          },
        ],
      });
      window.onresize = function () {
        //自适应大小
        myChart.resize();
      };
    };
    onMounted(() => {
      getChartData(store.state.POIname, store.state.POItype);
      nextTick(() => {
        chart();
      });
    });
    return { data, chart, getChartData };
  },
};
</script>
<style lang="less" scoped>
//@import url(); 引入公共css类
#customerChart {
  width: 100%;
  height: 93%;
  // position: absolute;
  // top: 110px;
  // left: 50%;
  // transform: translateX(-50%);
  // z-index: 10;
}
</style>
